/*******************
VARIABLES
*******************/
var videoRef, videoThumb, closeBtn, panelExpandView, panelCollapseView, clickthroughExpandBtn, clickthroughCollapseBtn, videoContainerRef;
/*******************
INITIALIZATION
*******************/
function checkIfAdKitReady(event) {
	adkit.onReady(initializeCreative);
}

function initializeCreative() {
	initializeGlobalVariables();

	// Fix for Chrome browser version 68 and above style updates to native video controls which cause the "clickthrough-expand" button to cover the native browser video controls.
	// Non-functional during local testing.
	if (typeof EB.browser !== "undefined" && (EB.browser.chrome === true && EB.browser.ver >= 68)) {
		document.getElementById("clickthrough-expand").style.bottom = "25%";
	}

	addEventListeners();
}

function initializeGlobalVariables() {
	panelExpandView = document.getElementById("panel-expanded");
	panelCollapseView = document.getElementById("panel-collapsed");
	clickthroughExpandBtn = document.getElementById("clickthrough-expand");
	clickthroughCollapseBtn = document.getElementById("clickthrough-collapse");
	videoThumb = document.getElementById("video-thumb-1");
	closeBtn = document.getElementById("close-container");
	videoContainerRef = document.getElementById("video-container");
}

function addEventListeners() {
	clickthroughExpandBtn.addEventListener("click", onClickthroughExpand);
	clickthroughCollapseBtn.addEventListener("click", onClickthroughCollapse);
	videoThumb.addEventListener("click", immersiveTakeover.onExpandClick);
	closeBtn.addEventListener("click", immersiveTakeover.onCollapseClick);
	window.addEventListener("resize", onWindowResize);
}
/*******************
EVENT HANDLERS
*******************/
function onClickthroughExpand() {
	EB.clickthrough("click_header_expand");
}

function onClickthroughCollapse() {
	EB.clickthrough("click_header_collapse");
}
/*******************
CALLBACK FUNCTIONS
*******************/
function afterShowPanelContent() {
	//Implement code logic to fire when the panel is shown
	resizeFont();
	//initVideo: will add the video interactions for tracking and you will able to use the callbacks for the video(afterVideoEnd,afterVideoPlay,afterVideoPause,afterVolumeChange)

	immersiveTakeover.initVideo(videoContainerRef);
}

function afterExpandAnimStart(args) {
	//Implement code logic to fire on Expand animation start
	panelCollapseView.style.display = "none";
	panelExpandView.style.display = "block";
	clickthroughExpandBtn.style.display = "none";

	//resizeVideo: change the size of the video respect of the video container you use.
	immersiveTakeover.resizeVideo(videoContainerRef); //fix a bug in Android with the address bar

	setTimeout(function() {
		if (!args.isAutoExpand) {
			videoRef.muted = false;
			videoRef.play();
		}
	}, 200);
}

function afterExpandAnimComplete(args) {
	//Implement code logic to fire on Expand animation Complete
	//resizeVideo: change the size of the video respect of the video container you use.
	immersiveTakeover.resizeVideo(videoContainerRef);
	clickthroughExpandBtn.style.display = "block"; //Bug in IE11: the elements close to the video control could be cutoff
	resizeFont();
}

function afterCollapseAnimStart(args) {
	//Implement code logic to fire on Collapse animation start
}

function afterCollapseAnimComplete(args) {
	//Implement code logic to fire on Collapse animation Complete
	panelCollapseView.style.display = "block";
	panelExpandView.style.display = "none";

	if (videoRef !== "undefined" && videoRef.paused === false) {
		videoRef.pause();
	}

	resizeFont();
}
/*******************
CALLBACK VIDEO FUNCTIONS
*******************/
function afterVideoReady(args) {
	//Implement code logic to fire when the video ready / video tag injected into the page
	videoRef = args.video;
}

function afterVideoEnd(args) {
	//Implement code logic to fire when the video End
}

function afterVideoPlay(args) {
	//Implement code logic to fire when the video Play
}

function afterVideoPause(args) {
	//Implement code logic to fire when the video Pause
}

function afterVolumeChange(args) {
	//Implement code logic to fire when the volume Change
}

function adWasClicked(args) {
	if (args.isMobile && !args.isIOS) {
		videoRef.load();
		setTimeout(function() {
			videoRef.pause();
		}, 100);
	}
	else {
		videoRef.pause();
	}
}
/*******************
CREATIVE FUNCTIONS
*******************/
function onWindowResize(args) {
	resizeFont();
	//resizeVideo will modify the size of the video respect to the video container you send.
	immersiveTakeover.resizeVideo(videoContainerRef);
}

function resizeFont() {
	//fontResize(elemRef, minFontSize) is an utility to resize the fontSize depending on the width of the panel
	immersiveTakeover.fontResize(clickthroughExpandBtn, 4);
	immersiveTakeover.fontResize(clickthroughCollapseBtn, 4);
}
/*******************
END OF CREATIVE FUNCTIONS
*******************/
//config = {
//		panel: define the type of the element for the immersiveTakeover, //options: header, left_gutter, right_gutter, background, videoskin, controls or standard
//in the case you want to use the resizeVideo function in the panel with video to get a good aspectRatio, you will need:
//      videoWidth: width of your video,
//      videoHeight: height of your video
// To set video source URL use the following.
// For single video codec use a string as the value.  EG: videoPoster: "videos/video1.jpg"
// For multiple video codecs use an array.  EG: videoPoster: ["videos/video1.mp4", "videos/video1.webm"]
//		videoURL: "videos/video1.mp4",
// To set video poster image source URL use the following.
//		videoPoster: "videos/video1.jpg"
//};
var config = {
	panel: "header",
	videoWidth: 1100,
	videoHeight: 416,
	videoURL: "videos/video1.mp4", // For multiple codecs use an array.  EG: ["videos/video1.mp4", "videos/video1.webm"]
	videoPoster: "videos/video1.jpg"
};
var immersiveTakeover = new immersiveTakeover(config);
window.addEventListener("load", checkIfAdKitReady);
